'use client'

import React, { useState } from 'react'
import { Project } from '@/typings/project'
import { ProjectCard } from '@/components/ProjectCard'

const Page = () => {
  const projects: Project[] = [
    {
      name: 'Project Alpha',
      description: 'Description for Project Alpha',
      category: 'Web',
      imageUrl: 'https://via.placeholder.com/150',
      socials: { Github: 'https://github.com', YouTube: 'https://youtube.com' },
      languages: ['Java', 'TypeScript'],
      tags: ['Frontend', 'Backend'],
    },
    {
      name: 'Project Beta',
      description: 'Description for Project Beta',
      category: 'Minecraft',
      imageUrl: 'https://via.placeholder.com/150',
      socials: { Github: 'https://github.com' },
      languages: ['Rust', 'Go'],
      tags: ['1.8', 'Fullstack'],
    },
    {
      name: 'Project Gamma',
      description: 'Description for Project Gamma',
      category: 'Discord',
      imageUrl: 'https://via.placeholder.com/150',
      socials: { YouTube: 'https://youtube.com' },
      languages: ['TypeScript'],
      tags: ['Backend', 'Archived'],
    },
    {
      name: 'Project Delta',
      description: 'Description for Project Delta',
      category: 'Unity',
      imageUrl: 'https://via.placeholder.com/150',
      socials: {},
      languages: ['Java'],
      tags: ['1.17', 'Frontend'],
    },
    {
      name: 'Project Epsilon',
      description: 'Description for Project Epsilon',
      category: 'Misc',
      imageUrl: 'https://via.placeholder.com/150',
      socials: { Github: 'https://github.com', YouTube: 'https://youtube.com' },
      languages: ['Go', 'Rust'],
      tags: ['Fullstack', 'Paper'],
    },
    // Add more projects to test pagination
    {
      name: 'Project Zeta',
      description: 'Description for Project Zeta',
      category: 'Misc',
      imageUrl: 'https://via.placeholder.com/150',
      socials: { Github: 'https://github.com', YouTube: 'https://youtube.com' },
      languages: ['Go', 'Rust'],
      tags: ['Fullstack', 'Paper'],
    },
    {
      name: 'Project Eta',
      description: 'Description for Project Eta',
      category: 'Misc',
      imageUrl: 'https://via.placeholder.com/150',
      socials: { Github: 'https://github.com', YouTube: 'https://youtube.com' },
      languages: ['Go', 'Rust'],
      tags: ['Fullstack', 'Paper'],
    },
    // Add as many projects as needed to test
  ]

  const [currentPage, setCurrentPage] = useState(1)
  const [itemsPerPage] = useState(4)
  const [filterTag, setFilterTag] = useState<string | null>(null)
  const [sortOrder, setSortOrder] = useState<'asc' | 'desc'>('asc')

  const handleFilterChange = (event: React.ChangeEvent<HTMLSelectElement>) => {
    setFilterTag(event.target.value === 'All' ? null : event.target.value)
    setCurrentPage(1) // Reset to the first page when filter changes
  }

  const handleSortChange = (event: React.ChangeEvent<HTMLSelectElement>) => {
    setSortOrder(event.target.value as 'asc' | 'desc')
    setCurrentPage(1) // Reset to the first page when sort order changes
  }

  const filteredProjects = filterTag
    ? projects.filter(project => project.tags.includes(filterTag))
    : projects

  const sortedProjects = [...filteredProjects].sort((a, b) => {
    if (sortOrder === 'asc') {
      return a.name.localeCompare(b.name)
    } else {
      return b.name.localeCompare(a.name)
    }
  })

  const indexOfLastItem = currentPage * itemsPerPage
  const indexOfFirstItem = indexOfLastItem - itemsPerPage
  const currentProjects = sortedProjects.slice(
    indexOfFirstItem,
    indexOfLastItem
  )

  const totalPages = Math.ceil(sortedProjects.length / itemsPerPage)

  return (
    <div className="flex min-h-screen flex-col items-center p-4 md:p-8">
      <div className="mb-8 text-2xl font-bold">Matz Hilven</div>
      <div className="mb-4 flex gap-4">
        <select onChange={handleFilterChange} className="rounded border p-2">
          <option value="All">All Tags</option>
          {[...new Set(projects.flatMap(project => project.tags))].map(tag => (
            <option key={tag} value={tag}>
              {tag}
            </option>
          ))}
        </select>
        <select onChange={handleSortChange} className="rounded border p-2">
          <option value="asc">Sort by Name (A-Z)</option>
          <option value="desc">Sort by Name (Z-A)</option>
        </select>
      </div>
      <div className="mx-4 flex flex-wrap justify-center gap-4">
        {currentProjects.map((project: Project, index: number) => (
          <ProjectCard project={project} key={index} />
        ))}
      </div>
      <div className="mt-4 flex gap-4">
        <button
          onClick={() => setCurrentPage(currentPage - 1)}
          disabled={currentPage === 1}
          className="rounded border px-4 py-2 disabled:opacity-50"
        >
          Previous
        </button>
        <button
          onClick={() => setCurrentPage(currentPage + 1)}
          disabled={currentPage === totalPages}
          className="rounded border px-4 py-2 disabled:opacity-50"
        >
          Next
        </button>
      </div>
    </div>
  )
}

export default Page
