import { Project, Tag, Language, Social } from '@/typings/project'
import {
  IconBrandGithub,
  IconBrandYoutube,
  IconCoffee,
  IconBrandRust,
  IconBrandGolang,
  IconBrandTypescript,
} from '@tabler/icons-react'

type Props = {
  project: Project
}

const socialIcons: Record<Social, React.JSX.Element> = {
  Github: <IconBrandGithub className="h-5 w-5" />,
  YouTube: <IconBrandYoutube className="h-5 w-5" />,
}

const languageIcons: Record<Language, React.JSX.Element> = {
  Java: <IconCoffee className="h-5 w-5" />,
  Rust: <IconBrandRust className="h-5 w-5" />,
  Go: <IconBrandGolang className="h-5 w-5" />,
  TypeScript: <IconBrandTypescript className="h-5 w-5" />,
}

const tagStyles: Record<Tag, string> = {
  '1.8': 'text-orange-500 border-orange-500',
  '1.17': 'text-orange-500 border-orange-500',
  Paper: 'text-blue-500 border-blue-500',
  Bungee: 'text-blue-500 border-blue-500',
  Frontend: 'text-cyan-500 border-cyan-500',
  Backend: 'text-cyan-500 border-cyan-500',
  Fullstack: 'text-cyan-500 border-cyan-500',
  Archived: 'text-gray-600 border-gray-600',
}

export const ProjectCard = ({ project }: Props) => {
  return (
    <div className="h-80 w-80 transform overflow-hidden rounded-lg bg-white shadow-md transition-transform hover:-translate-y-2">
      <img
        src={project.imageUrl}
        alt={project.name}
        className="h-40 w-full object-cover"
      />
      <div className="flex flex-grow flex-col justify-between p-4">
        <div>
          <div className="mb-2 text-xl font-bold">{project.name}</div>
          <div className="mb-2 flex flex-wrap gap-2">
            {project.tags.map(tag => (
              <span
                key={tag}
                className={`rounded-full border px-2 py-1 text-xs font-semibold ${tagStyles[tag] || 'border-gray-500 text-gray-500'}`}
              >
                {tag}
              </span>
            ))}
          </div>
          <div className="text-sm text-gray-700">{project.description}</div>
        </div>
        <div className="mt-4 flex items-center justify-between">
          <div className="flex space-x-4">
            {Object.entries(project.socials).map(([social, url]) => (
              <a
                key={social}
                href={url}
                target="_blank"
                rel="noopener noreferrer"
                className="text-gray-700"
              >
                {socialIcons[social as Social]}
              </a>
            ))}
          </div>
          <div className="flex space-x-2">
            {project.languages.map(language => (
              <span key={language} className="text-xl text-gray-700">
                {languageIcons[language]}
              </span>
            ))}
          </div>
        </div>
      </div>
    </div>
  )
}
